@@ -16,42 +16,45 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
 ** Bug reports and questions can be sent to kde-devel@kde.org
 */
 
-
-#include "../config.h"
 // qt headers
-#include <qlabel.h>
+#include <QtGui/QLabel>
+//Added by qt3to4:
+#include <QtGui/QShowEvent>
+#include <QtCore/QList>
+#include <QtGui/QBoxLayout>
+#include <QtGui/QCloseEvent>
+#include <QtGui/QListWidget>
+#include <QtGui/QApplication>
 
 #include <klocale.h>
 #include <kglobal.h>
 #include <kglobalsettings.h>
-#include <klistview.h>
 #include <kseparator.h>
 #include <kdebug.h>
 #include <kpushbutton.h>
-#include <kstdguiitem.h>
+#include <KStandardGuiItem>
 
 #include "pkgOptions.h"
 #include "managementWidget.h"
-#include "debInterface.h"
 #include "kpackage.h"
-#include "options.h"
 
 ///////////////////////////////////////////////////////////////////////////
 ///////////////////////////////////////////////////////////////////////////
 
 pkgOptions::pkgOptions(pkgInterface *pki, QWidget *parent, const QString &caption)
-  :  KDialog(parent,0,TRUE)
+  :  QDialog(parent)
 {
   //  setFrameStyle(QFrame::Raised | QFrame::Panel);
 
+//  kDebug() << "pkgOptions::pkgOptions\n";
   pkgInt = pki;
 
   hide();
@@ -69,7 +72,7 @@ pkgOptions::~pkgOptions()
 }
 
 // Set up the sub-widgets
-void pkgOptions::setupWidgets(QPtrList<param> &pars)
+void pkgOptions::setupWidgets(QList<param *> &pars)
 {
   int i;
 
@@ -79,23 +82,24 @@ void pkgOptions::setupWidgets(QPtrList<param> &pars)
   f.setBold(true);
   f.setPointSize(f.pointSize()+6);
   title->setFont(f);
-  //  title->setAutoResize(TRUE);
+  //  title->setAutoResize(true);
   //  title->update();
 
-  installButton = new QPushButton(insType,this);
-  cancelButton = new KPushButton(KStdGuiItem::cancel(),this);
+  installButton = new QPushButton(insType);
+  cancelButton = new KPushButton(KStandardGuiItem::cancel());
   // count number of buttons
   bnumber = pars.count();
 
   Boxs = new QCheckBox *[bnumber];
-  param *p;
   i = 0;
-  for ( p=pars.first(); p != 0; p=pars.next(), i++ ) {
-    Boxs[i] = new QCheckBox(p->name, this);
+//  for ( p=pars.first(); p != 0; p=pars.next(), i++ ) {
+  foreach (param *p, pars) {
+    Boxs[i] = new QCheckBox(p->name);
     Boxs[i]->setChecked(p->init);
+    i++;
   }
 
-  Keep = new QCheckBox(i18n("Keep this window"), this);
+  Keep = new QCheckBox(i18n("Keep this window"));
 
   // Connections
   connect(installButton,SIGNAL(clicked()),SLOT(pkginstallButtonClicked()));
@@ -103,34 +107,36 @@ void pkgOptions::setupWidgets(QPtrList<param> &pars)
   connect(Keep, SIGNAL(toggled(bool)), SLOT(keepToggle(bool)));
 
   // Do the layout
-  vlayout = new QBoxLayout(this, QBoxLayout::TopToBottom, marginHint(), spacingHint());
+  vlayout = new QBoxLayout(this, QBoxLayout::TopToBottom);
   vlayout->addWidget(title,0);
 
   {
-    hlayout = new QBoxLayout(vlayout,QBoxLayout::LeftToRight, spacingHint());
+    hlayout = new QBoxLayout(vlayout,QBoxLayout::LeftToRight);
 
     {
-      layout = new QBoxLayout(hlayout,QBoxLayout::TopToBottom, spacingHint());
+      layout = new QBoxLayout(hlayout,QBoxLayout::TopToBottom);
 
-      packages = new KListView(this);
+      packages = new QListWidget();
       layout->addWidget(packages,20);
-      packages->addColumn(i18n("PACKAGES"),200);
+      
+      QStringList heads;
+
+      connect(packages, SIGNAL(itemClicked( QListWidgetItem *)),
+	      this, SLOT(slotSearch( QListWidgetItem *)));
 
-      connect(packages, SIGNAL(selectionChanged ( QListViewItem * )),
-	    this, SLOT(slotSearch( QListViewItem * )));
 
       layout->addStretch(1);
       for (i = 0; i < bnumber; i++) {
 	layout->addWidget(Boxs[i],1);
       }
-      layout->addWidget(new KSeparator(KSeparator::HLine, this), 2);
+      layout->addWidget(new KSeparator(Qt::Horizontal), 2);
 
       QBoxLayout *slayout = new QBoxLayout(layout, QBoxLayout::LeftToRight);
       slayout->addStretch(1);
       slayout->addWidget(Keep, 1);
       slayout->addStretch(1);
 
-      layout->addWidget(new KSeparator(KSeparator::HLine, this), 2);
+      layout->addWidget(new KSeparator(Qt::Horizontal), 2);
 
       QBoxLayout *buttons = new QBoxLayout(QBoxLayout::LeftToRight);
       layout->addLayout(buttons);
@@ -140,75 +146,113 @@ void pkgOptions::setupWidgets(QPtrList<param> &pars)
       buttons->addWidget(cancelButton,2);
     }
     {
-      term = new kpTerm(kpty,this);
+      term = new kpTerm(kpty);
       hlayout->addWidget(term, 1000);
     }
   }
+  setLayout(vlayout);
   resize(800, 400);
 }
 
-void pkgOptions::setup(packageInfo *p, const QString &type) {
-  QPtrList<packageInfo> *pl = new QPtrList<packageInfo>;
-  pl->append(p);
-  setup(pl,type);
+bool pkgOptions::setup(packageInfo *p) {
+//  QList<packageInfo *> *pl = new QList<packageInfo *>;
+  QList<packageInfo *> pl;
+  pl.append(p);
+  return setup(pl);
 }
 
-void pkgOptions::setup(QPtrList<packageInfo> *pl, const QString &)
+void pkgOptions::resetPackages(bool init)
+{
+  //kDebug() << "resetPackages()\n";
+  installButton->setEnabled(false);
+
+  int packCount = packList.count();
+  
+  packListChecked.clear();
+  QStringList checked;
+  QSet<QString> isChecked;
+  for (int i = 0; i < packCount; i++) {
+    QListWidgetItem *w = packages->item(i);
+      if (w->checkState() == Qt::Checked) {
+	kDebug() << "CK=" << w->text() << "\n";
+	checked << w->text();
+	isChecked.insert(w->text());
+      }
+  }
+  
+  if (checked == checkedPackages && !init) 
+    return;
+  
+  QApplication::setOverrideCursor( Qt::WaitCursor );
+  checkedPackages = checked;
+  
+  packListChecked.clear();
+  foreach (packageInfo *p, packList) {
+//    kDebug() << "PC=" << p->fetchFilename() << "\n";
+    if (isChecked.contains(p->fetchFilename())) {
+      packListChecked << p;
+    }
+  }
+  
+  bool cancel;
+  QStringList rlist;
+  if (checked.count() > 0) {
+    rlist = pkgInt->listInstalls(checked, installer, cancel);
+  }
+//  kDebug() << "rlist=" << rlist << "\n";
+ 
+  QListWidgetItem *wd;
+  while ((wd = packages->takeItem(packCount))) {
+//    kDebug() << "packages del " << wd->text() << "\n";
+    delete wd;
+  }
+  
+  foreach (const QString &ritem, rlist) {
+    if (!isChecked.contains(ritem)) {
+       new QListWidgetItem(ritem, packages);
+    }
+ }
+ 
+ if (packListChecked.count() > 0)
+   installButton->setEnabled(true);
+
+  QApplication::restoreOverrideCursor();
+}
+
+bool pkgOptions::setup(QList<packageInfo *> pl)
 {
  QString s;
- modified = FALSE;
+ modified = false;
 
  packList = pl;
-
-  packages->clear();
-  packageInfo *p;
-
+ 
   QStringList plist, rlist, clist;
-  QDict<QString> dict;
-  QString mark("x");
-  for ( p = pl->first(); p != 0; p = pl->next() ) {
-    QString file =  p->getFilename();
-    plist += p->getProperty("name");
-    if (file.isEmpty()) {
-      clist += p->getProperty("name");
-    }
-    dict.insert(p->getProperty("name"), &mark);
+  QSet<QString> dict;
+//  kDebug() << "pl=" << pl << "\n";
+  
+  foreach (packageInfo *p, pl) {
+    plist += p->fetchFilename();
+    dict.insert(p->getInfo("name"));
   }
-
-  packageInfo *pk;
-  if (clist.count() > 0) {
-    rlist = pkgInt->listInstalls(clist, installer);
-    for ( QStringList::Iterator it = rlist.begin(); it != rlist.end(); ++it ) {
-      if (!dict[*it]) {
-	plist.append(*it);
-	QString dirIndex = *it + pkgInt->typeID;
-	if (installer) {
-	  pk = kpackage->management->dirUninstPackages->find(dirIndex);
-	} else {
-	  pk = kpackage->management->dirInstPackages->find(dirIndex);
-	}
-	if (pk) {
-	  //	  kdDebug() << "FF=" << dirIndex << "\n";
-	  pl->append(pk);
-	} else {
-	  //	  kdDebug() << "uF=" << dirIndex << "\n";
-	}
-      }
-    }
-  }
-
- if (plist.count() == 1) {
-   s = i18n("%1: 1 %2 Package").arg(insType).arg(pkgInt->name);
- } else {
-   s = i18n("%1: %2 %3 Packages").arg(insType).arg(plist.count()).arg(pkgInt->name);
- }
+//  kDebug() << "clist=" << clist << "\n";
+ 
+ s = i18np("%2: 1 Package","%2: %1 Packages",plist.count(),insType);
  title->setText(s);
+// kDebug() << "plist=" << plist << "\n";
 
-  for (QStringList::Iterator pit = plist.begin(); pit != plist.end(); ++pit ) {
-    //    kdDebug() << "P=" << *pit << "\n";
-    new QListViewItem(packages, *pit);
+ packages->clear();
+ int i = 0;
+  foreach (const QString &pit, plist) {
+    QListWidgetItem *pw = new QListWidgetItem(pit, packages);
+    if (i < packList.count()) {
+      pw->setCheckState(Qt::Checked);
+    }
+    i++;
   }
-  cancelButton->setGuiItem(KStdGuiItem::cancel());
+  
+  cancelButton->setGuiItem(KStandardGuiItem::cancel());
+  resetPackages(true);
+  return true;
 }
 
 // install button has been clicked....so install the package
@@ -216,7 +260,7 @@ void pkgOptions::pkginstallButtonClicked()
 {
   int i;
   QStringList r;
-  modified = TRUE;
+  modified = true;
 
   // Collect data from check boxes
   int installFlags = 0;
@@ -225,12 +269,12 @@ void pkgOptions::pkginstallButtonClicked()
     installFlags |= (Boxs[i]->isChecked()) << i;
   }
 
-  test = FALSE;
-  QString s = doPackages(installFlags, packList, test);
+  test = false;
+  QString s = doPackages(installFlags, packListChecked, test);
   // A "0=" or "1=" indicates it was actually (un)installed by the doPackages
   // routine instead of just returning a command to execute
 
-  kdDebug() <<  "S=" << s << "\n";
+//            kDebug() <<  "S=" << s << "\n";
   if (s == "0=") {
     cancelButtonClicked();
   } else if (s.left(2) == "1=") {
@@ -239,37 +283,39 @@ void pkgOptions::pkginstallButtonClicked()
     connect(term,SIGNAL(result(QStringList &, int)),
 	 this,SLOT(slotResult(QStringList &, int)));
 
-    installButton->setEnabled(FALSE);
+    installButton->setEnabled(false);
 
     if (term->run(s, r)) {
-      running = TRUE;
-      cancelButton->setGuiItem(KStdGuiItem::cancel());
+      running = true;
+      cancelButton->setGuiItem(KStandardGuiItem::cancel());
     } else {
       reset();
     }
   }
 }
 
-void pkgOptions::slotSearch(QListViewItem *item)
+void pkgOptions::slotSearch(QListWidgetItem *item)
 {
-  QString s = item->text(0);
-  kdDebug() << "searchI=" << s << "h=" << pkgInt->head <<"\n";
+  if (item) {
+    QString s = item->text();
+    // kDebug() << "searchI=" << s << "\n";
 
-  packageInfo *p;
-  for ( p = packList->first(); p != 0; p = packList->next() ) {
-    if (s == p->getProperty("name")) {
-      kpackage->management->doChangePackage(p);
-      break;
+    foreach (packageInfo *p, packList) {
+      if (s == p->getInfo("name")) {
+        kpackage->management->doChangePackage(p);
+        break;
+      }
     }
+    resetPackages(false);
   }
 }
 
 void pkgOptions::reset() {
-  installButton->setEnabled(TRUE);
+  installButton->setEnabled(true);
   cancelButton->setGuiItem(KGuiItem(i18n("Done")));  //clear icon
   disconnect(term,SIGNAL(result(QStringList &, int)),
 	 this,SLOT(slotResult(QStringList &, int)));
-  running = FALSE;
+  running = false;
 }
 
 void pkgOptions::slotResult(QStringList &, int ret)
@@ -300,40 +346,38 @@ void pkgOptions::cancelButtonClicked()
 }
 
 void pkgOptions::closeEvent ( QCloseEvent * e ) {
-  kdDebug() << "pkgOptions::QCloseEvent\n";
+//  kDebug() << "pkgOptions::QCloseEvent\n";
   terminate();
-   
+
   QWidget::closeEvent (e);
 }
 
 void pkgOptions::showEvent ( QShowEvent *e ) {
-  //  kdDebug() << "pkgOptions::showEvent\n";
+  //  kDebug() << "pkgOptions::showEvent\n";
   getKeep();
 
-  modified = FALSE;
-  running = FALSE;
+  modified = false;
+  running = false;
 
   QWidget::showEvent(e);
 }
 
 void pkgOptions::keepToggle(bool kp)
 {
-  //  kdDebug() << "KEEP " << kp << "\n";
+  //  kDebug() << "KEEP " << kp << "\n";
 
-  KConfig *config = kapp->config();
+  KConfigGroup config = KGlobal::config()->group("Kpackage");
 
-  config->setGroup("Kpackage");
-  config->writeEntry("keepIWin", kp);
+  config.writeEntry("keepIWin", kp);
 
   keep = kp;
 }
 
 void pkgOptions::getKeep()
 {
-    KConfig *config = kapp->config();
-    config->setGroup("Kpackage");
-    keep =  config->readBoolEntry("keepIWin", true);
-  kdDebug() << "getKEEP " << keep << "\n";
+    KConfigGroup config(KGlobal::config(), "Kpackage");
+    keep =  config.readEntry("keepIWin", true);
+//            kDebug() << "getKeeP " << keep << "\n";
     Keep->setChecked(keep);
 
 }
@@ -343,12 +387,13 @@ void pkgOptions::getKeep()
 pkgOptionsI::pkgOptionsI(pkgInterface *pkg, QWidget *parent):
   pkgOptions(pkg, parent, i18n("Install"))
 {
+//  kDebug() << "pkgOptionsI::pkgOptionsI\n";
   insType = i18n("Install");
-  installer = TRUE;
+  installer = true;
   setupWidgets(pkg->paramsInst);
 }
 
-QString pkgOptionsI::doPackages(int installFlags, QPtrList<packageInfo> *p, bool &test)
+QString pkgOptionsI::doPackages(int installFlags, QList<packageInfo *> p, bool &test)
 {
   return pkgInt->install(installFlags, p, test);
 }
@@ -358,12 +403,13 @@ QString pkgOptionsI::doPackages(int installFlags, QPtrList<packageInfo> *p, bool
 pkgOptionsU::pkgOptionsU(pkgInterface *pkg, QWidget *parent):
   pkgOptions(pkg, parent, i18n("Uninstall"))
 {
+//  kDebug() << "pkgOptionsU::pkgOptionsU\n";
   insType = i18n("Uninstall");
-  installer = FALSE;
+  installer = false;
   setupWidgets(pkg->paramsUninst);
 }
 
-QString pkgOptionsU::doPackages(int installFlags, QPtrList<packageInfo> *p, bool &test)
+QString pkgOptionsU::doPackages(int installFlags, QList<packageInfo *> p, bool &test)
 {
   return pkgInt->uninstall(installFlags, p, test);
 }
