@@ -6,24 +6,35 @@
     email                : putzer@kde.org
  ***************************************************************************/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; version 2.                              *
- *                                                                         *
- ***************************************************************************/
+/*
+   Copyright 2000 Peter Putzer <putzer@kde.org>
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
 
 #ifndef KSV_IOCORE_H
 #define KSV_IOCORE_H
 
-#include <qdir.h>
-#include <qstring.h>
+#include <QDir>
+
+//Added by qt3to4:
+#include <Q3ValueList>
 
-#include <ktrader.h>
 #include <kservice.h>
 
-template<class T> class QValueList;
+template<class T> class Q3ValueList;
 class QFileInfo;
 class QDataStream;
 
@@ -51,10 +62,10 @@ namespace ksv
                             KSVDragList** stop);
 
     bool loadSavedConfiguration (QDataStream&,
-                                 QValueList<KSVData>* start,
-                                 QValueList<KSVData>* stop);
+                                 Q3ValueList<KSVData>* start,
+                                 Q3ValueList<KSVData>* stop);
 
-    KTrader::OfferList servicesForFile (const QString& filename);
+    KMimetypeTrader::OfferList servicesForFile (const QString& filename);
     KService::Ptr preferredServiceForFile (const QString& filename);
 
   } // namespace IO
